using AutoScan;
using Microsoft.Extensions.Logging;

namespace CasaBotApp.Extensions;

public static class CommandRegister
{
    public static void RegisterCommands(BotHandler botHandler, AutoScanApp autoScanApp)
    {
        botHandler.RegisterCommand(new BotCommand
        {
            Command = "/soyandre",
            Description = "Soy Andre",
            Action = async (message, ctx) =>
            {
                await ctx.Responder(message, "Hola vida, te amo mucho ❤️");
            }
        });
        botHandler.RegisterCommand(new BotCommand
        {
            Command = "/startScan",
            Description = "Start a scan of last night images",
            Action = async (message, ctx) =>
            {
                await ctx.Responder(message, "Starting scan 🔍📼");
                await autoScanApp.StartNewScan();
            }
        });
    }
    
    public static void UpdateOnScanCompleted(BotHandler botHandler, AutoScanApp autoScanApp, ILogger logger)
    {
        autoScanApp.OnScanCompleted = async options =>
        {
            logger.LogInformation("Scan completed at {At}", DateTime.Now);
            try
            {
                //list all the images in the detection folder
                if (options.Scanner?.DetectionFolder is null)
                    return;
                var images = Directory.GetFiles(options.Scanner.DetectionFolder , "*.jpg");
                await botHandler.Update($"Scan completed, found {images.Length} images");
                await botHandler.UpdatePhotos(images);    
            }catch(Exception ex)
            {
                logger.LogError(ex, "Error while sending message");
            }
        };
    }
}